@@ -1040,7 +1040,7 @@ class OMFITmhdin(OMFITnamelist):
                 ods['pf_active.coil'][c]['identifier'] = f'PF{c}'
                 ods['pf_active.coil'][c]['element'][e]['name'] = f'PF{c}_{e}'
                 ods['pf_active.coil'][c]['element'][e]['identifier'] = f'PF{c}_{e}'
-                ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i] * turnfc[e]
+                ods['pf_active.coil'][c]['element'][e]['turns_with_sign'] = turns[i] * turnfc[elements_id[i]]
                 if angle1[i] == 0 and angle2[i] == 0:
                     rect = ods['pf_active.coil'][c]['element'][e]['geometry.rectangle']
                     rect['r'] = r[i]
