@@ -1251,7 +1251,7 @@ class OMFITldpi(OMFITncDataset):
                     fig, ax = pyplot.subplots(subplot_kw={'aspect': 'equal'})
                 else:
                     # OMFIT (or the pyplot.gcf needed to check OMFIT) made a empty figure for us
-                    ax = fig.add_subplot(111, aspect='equal')
+                    ax = pyplot.subplot(111, aspect='equal')
             plot_2d(ax)
         else:
             fig = kwargs.pop('figure', None)
@@ -1266,21 +1266,21 @@ class OMFITldpi(OMFITncDataset):
                     pass
 
             # 1D plots
-            ax = fig.add_subplot(322)
+            ax = pyplot.subplot(322)
             self['q'].plot(ax)
             pyplot.setp(ax.get_xticklabels(), visible=False)
             ax.set_xlabel('')
             ax.yaxis.set_major_locator(pyplot.MaxNLocator(nbins=4))
-            ax = fig.add_subplot(324, sharex=ax)
+            ax = pyplot.subplot(324, sharex=ax)
             self['p'].plot(ax)
             pyplot.setp(ax.get_xticklabels(), visible=False)
             ax.set_xlabel('')
             ax.yaxis.set_major_locator(pyplot.MaxNLocator(nbins=4))
-            ax = fig.add_subplot(326, sharex=ax)
+            ax = pyplot.subplot(326, sharex=ax)
             self['f'].plot(ax)
             ax.yaxis.set_major_locator(pyplot.MaxNLocator(nbins=4))
 
-            ax = fig.add_subplot(131)
+            ax = pyplot.subplot(131)
             ax.set_frame_on(False)
             ax.xaxis.set_ticks_position('bottom')
             ax.yaxis.set_ticks_position('left')
